import logging
from logging.handlers import RotatingFileHandler

# 配置日志
logging.basicConfig(
    level=logging.INFO,
    format='%(asctime)s - %(name)s - %(levelname)s - %(message)s',
    handlers=[
        logging.StreamHandler(),
        RotatingFileHandler('app.log', maxBytes=10485760, backupCount=5, encoding='utf-8')
    ]
)
logger = logging.getLogger(__name__)
logger.propagate = True

# 导入FastAPI及相关模块
import os
from fastapi import FastAPI
import uvicorn
from router.knowledge_dify import dify_kb_router
from router.knowledge_saas import saas_kb_router
from router.text_search import text_search_router

# 创建FastAPI应用
app = FastAPI(title="医疗百科问答系统")
app.include_router(dify_kb_router)
app.include_router(saas_kb_router)
app.include_router(text_search_router)

if __name__ == "__main__":
    logger.info('Starting uvicorn server...2222')
    #uvicorn main:app --host 0.0.0.0 --port 8000 --reload
    uvicorn.run("main:app", host="0.0.0.0", port=8000, reload=True)

